# Changelog for crema  

## [0.0.5] - 2021-06-11  
### Added  
- This changelog.

### Changed  
- Refactored the structure of classes and functions for better organization and readability
- Updated and improved unit/system tests
- Huge speed increase in calculating confidence level estimates